@@ -1,11 +1,12 @@
 
-package org.virtualbox_6_0.jaxws;
+package org.virtualbox_6_1.jaxws;
 
 import java.util.ArrayList;
 import java.util.List;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlRootElement;
+import javax.xml.bind.annotation.XmlSchemaType;
 import javax.xml.bind.annotation.XmlType;
 
 
@@ -35,6 +36,7 @@ import javax.xml.bind.annotation.XmlType;
 @XmlRootElement(name = "IMedium_getAllowedTypesResponse")
 public class IMediumGetAllowedTypesResponse {
 
+    @XmlSchemaType(name = "string")
     protected List<MediumType> returnval;
 
     /**
